# -*- encoding: utf-8 -*-

##############################################################################
#
# Copyright (c) 2010 E.Samyn - esamyn@gmail.com
# Author: E.Samyn
#
# This file is part of the project_risk module
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsability of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# garantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; 
# If not, see <http://www.gnu.org/licenses/> or  write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################

from osv import fields, osv

#----- Upgrade task class
class task(osv.osv):
	_name = "project.task"
	_description = "Task"
	_inherit = "project.task"		
	_columns = {'project_risk_ids' : fields.one2many('project.risk', 'task_id', 'Risks'),
	}
task()

#----- Risk type Class
class project_risk_type(osv.osv):
	_name = "project.risk.type"
	_description = "Project risk types"
	_columns = {		
		'name' : fields.char("Type", size=64,required=True),
		'risk_type_description' : fields.text('Type description'),
	}  
project_risk_type()

#----- Risk Class
class project_risk(osv.osv):
	_name = "project.risk"
	_description = "Risk management on project tasks"
	_columns = {
		'task_id': fields.many2one('project.task', 'Task', ondelete='cascade'),
		'name' : fields.char("Risk", size=64,required=True),
		'state' : fields.selection([('draft','Draft'),
								   ('real','Real'),
								   ('undercontrol','Under control'),
								   ('occuring','Occuring'),
								   ('shut','Shut')],"State", help="Draft : potential risk to verify \nReal : the risk is verified and has to be treated \nUnder control : the risk is trated and under control \nOccuring : the risk becomes true \nShut : the risk is over"),
		'project_risk_description' : fields.text('Description'),
		'project_risk_type': fields.many2one('project.risk.type', 'Type', ondelete='cascade', help="Some common types : financial, organisational, technical, social, environnement,..."),
		'project_risk_source': fields.char("Source", size=150),
		'project_risk_impact': fields.text('Impact', help="Impact description"), 		
		'project_risk_financial_impact': fields.integer('Financial impact', help="Financial impact"),
		'project_risk_time_impact': fields.float('Time impact',digits=(3,2), help="Time impact in days"),
		'project_risk_seriousness': fields.selection([('minor','Minor'),
								   ('low','Low'),
								   ('significant','Significant'),
								   ('serious','Serious'),
								   ('critical','Critical')],"Seriousness"),
		'project_risk_probability': fields.selection([('0','0'),
								   ('10','10'),
								   ('20','20'),
								   ('30','30'),
								   ('40','40'),
								   ('50','50'),
								   ('60','60'),
								   ('70','70'),								   
								   ('80','80'),
								   ('90','90'),
								   ('99','99')],"Probability(%)"),
		'project_risk_response': fields.text('Response'),
		'project_test': fields.char("Source", size=150),
	}	
project_risk()
